==> krita-debuginfo-3.3.2.1-1.tar.xz: usr/src/debug/krita-3.3.2.1-1/plugins/tools/tool_crop/qrc_toolcrop.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/krita/krita-3.3.2.1-1.x86_64/src/krita-3.3.2.1/plugins/tools/tool_crop/tool_crop_cursor.png
  0x0,0x0,0x0,0xdb,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x20,0x0,0x0,0x0,0x20,0x4,0x3,0x0,0x0,0x0,0x81,0x54,0x67,0xc7,
  0x0,0x0,0x0,0x12,0x50,0x4c,0x54,0x45,0x0,0x0,0x0,0x8e,0x8e,0x8e,0xc6,0xc6,
  0xc6,0xff,0xff,0xff,0x0,0x0,0x0,0xff,0xff,0xff,0x2f,0x13,0xe1,0x3,0x0,0x0,
  0x0,0x4,0x74,0x52,0x4e,0x53,0x0,0x0,0x0,0x0,0xb3,0x93,0x66,0x9a,0x0,0x0,
  0x0,0x74,0x49,0x44,0x41,0x54,0x78,0xda,0xa5,0xce,0x31,0xa,0xc4,0x30,0xc,0x44,
  0xd1,0x29,0xb4,0x7d,0x8e,0x10,0xc,0xdb,0x7,0x72,0x81,0x10,0x34,0xbd,0xa,0xeb,
  0xfe,0x57,0x89,0x49,0xe1,0xe0,0x21,0xb,0x1b,0xf2,0xc1,0xcd,0x43,0xc8,0x2,0xf0,
  0x21,0xc6,0x14,0xca,0x97,0x65,0x7e,0x4,0x99,0x31,0xb7,0x77,0x81,0xfb,0x5e,0xdc,
  0x37,0xe8,0xc4,0x9b,0x5f,0x7e,0x9f,0x3e,0x41,0xaa,0xf7,0x60,0x21,0xc0,0xbe,0x27,
  0x6b,0xb6,0x6a,0x1f,0x30,0x3f,0xa3,0xec,0x30,0x5,0xa,0x58,0x8,0x10,0x23,0x58,
  0x8,0x10,0x23,0x58,0x8,0x10,0x2,0x7e,0xb6,0xe1,0x3a,0xbe,0xc5,0xc,0xc,0x11,
  0xf8,0x17,0xd6,0xa5,0xdb,0x1,0x97,0xdf,0x1e,0x82,0x6b,0x8e,0x76,0x79,0x0,0x0,
  0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // tool_crop_cursor.png
  0x0,0x14,
  0xf,0x27,0x59,0x87,
  0x0,0x74,
  0x0,0x6f,0x0,0x6f,0x0,0x6c,0x0,0x5f,0x0,0x63,0x0,0x72,0x0,0x6f,0x0,0x70,0x0,0x5f,0x0,0x63,0x0,0x75,0x0,0x72,0x0,0x73,0x0,0x6f,0x0,0x72,0x0,0x2e,
  0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/tool_crop_cursor.png
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0x7c,0x2c,0x70,0x40,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_toolcrop)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_toolcrop)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_toolcrop)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_toolcrop)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_toolcrop)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_toolcrop)(); }
   } dummy;
}

==> krita-debuginfo-3.3.3-1.tar.xz: usr/src/debug/krita-3.3.3-1/plugins/tools/tool_crop/qrc_toolcrop.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.3
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/krita/krita-3.3.3-1.i686/src/krita-3.3.3/plugins/tools/tool_crop/tool_crop_cursor.png
  0x0,0x0,0x0,0xdb,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x20,0x0,0x0,0x0,0x20,0x4,0x3,0x0,0x0,0x0,0x81,0x54,0x67,0xc7,
  0x0,0x0,0x0,0x12,0x50,0x4c,0x54,0x45,0x0,0x0,0x0,0x8e,0x8e,0x8e,0xc6,0xc6,
  0xc6,0xff,0xff,0xff,0x0,0x0,0x0,0xff,0xff,0xff,0x2f,0x13,0xe1,0x3,0x0,0x0,
  0x0,0x4,0x74,0x52,0x4e,0x53,0x0,0x0,0x0,0x0,0xb3,0x93,0x66,0x9a,0x0,0x0,
  0x0,0x74,0x49,0x44,0x41,0x54,0x78,0xda,0xa5,0xce,0x31,0xa,0xc4,0x30,0xc,0x44,
  0xd1,0x29,0xb4,0x7d,0x8e,0x10,0xc,0xdb,0x7,0x72,0x81,0x10,0x34,0xbd,0xa,0xeb,
  0xfe,0x57,0x89,0x49,0xe1,0xe0,0x21,0xb,0x1b,0xf2,0xc1,0xcd,0x43,0xc8,0x2,0xf0,
  0x21,0xc6,0x14,0xca,0x97,0x65,0x7e,0x4,0x99,0x31,0xb7,0x77,0x81,0xfb,0x5e,0xdc,
  0x37,0xe8,0xc4,0x9b,0x5f,0x7e,0x9f,0x3e,0x41,0xaa,0xf7,0x60,0x21,0xc0,0xbe,0x27,
  0x6b,0xb6,0x6a,0x1f,0x30,0x3f,0xa3,0xec,0x30,0x5,0xa,0x58,0x8,0x10,0x23,0x58,
  0x8,0x10,0x23,0x58,0x8,0x10,0x2,0x7e,0xb6,0xe1,0x3a,0xbe,0xc5,0xc,0xc,0x11,
  0xf8,0x17,0xd6,0xa5,0xdb,0x1,0x97,0xdf,0x1e,0x82,0x6b,0x8e,0x76,0x79,0x0,0x0,
  0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // tool_crop_cursor.png
  0x0,0x14,
  0xf,0x27,0x59,0x87,
  0x0,0x74,
  0x0,0x6f,0x0,0x6f,0x0,0x6c,0x0,0x5f,0x0,0x63,0x0,0x72,0x0,0x6f,0x0,0x70,0x0,0x5f,0x0,0x63,0x0,0x75,0x0,0x72,0x0,0x73,0x0,0x6f,0x0,0x72,0x0,0x2e,
  0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/tool_crop_cursor.png
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x60,0xd5,0x9a,0x8d,0xa0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_toolcrop)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_toolcrop)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_toolcrop)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_toolcrop)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_toolcrop)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_toolcrop)(); }
   } dummy;
}
